@@ -10,7 +10,7 @@ from typing import Any, cast
 import requests
 import tomli
 
-from licensecheck.types import UNKNOWN, PackageInfo
+from licensecheck.types import JOINS, UNKNOWN, PackageInfo
 
 
 def getPackageInfoLocal(requirement: str) -> PackageInfo:
@@ -41,7 +41,6 @@ def getPackageInfoLocal(requirement: str) -> PackageInfo:
 		return PackageInfo(
 			name=name,
 			version=version,
-			namever=f"{name}-{version}",
 			homePage=homePage,
 			author=author,
 			size=size,
@@ -68,7 +67,6 @@ def getPackageInfoPypi(requirement: str) -> PackageInfo:
 		return PackageInfo(
 			name=requirement,
 			version=info["version"],
-			namever=f"{requirement} {info['version']}",
 			homePage=info["home_page"],
 			author=info["author"],
 			size=int(response["urls"][-1]["size"]),
@@ -93,7 +91,7 @@ def licenseFromClassifierlist(classifiers: list[str]) -> str:
 			lice = val.split(" :: ")[-1]
 			if lice != "OSI Approved":
 				licenses.append(lice)
-	return ", ".join(licenses) if len(licenses) > 0 else UNKNOWN
+	return JOINS.join(licenses) if len(licenses) > 0 else UNKNOWN
 
 
 def getPackages(reqs: set[str]) -> set[PackageInfo]:
@@ -118,15 +116,15 @@ def getPackages(reqs: set[str]) -> set[PackageInfo]:
 	return packageinfo
 
 
-def getClassifiersLicense() -> dict[str, Any]:
-	"""Get the package classifiers and license from "setup.cfg", "pyproject.toml" or user input
+def getMyPackageMetadata() -> dict[str, Any]:
+	"""Get the package classifiers and license from "setup.cfg", "pyproject.toml"
 
 	Returns:
-		dict[str, Any]: {"classifiers": set[str], "license": str}
+		dict[str, Any]: {"classifiers": list[str], "license": str}
 	"""
 	if Path("setup.cfg").exists():
 		config = configparser.ConfigParser()
-		_ = config.read("setup.cfg")
+		config.read("setup.cfg")
 		if "license" in config["metadata"]:
 			return config["metadata"].__dict__
 	if Path("pyproject.toml").exists():
@@ -148,16 +146,15 @@ def getMyPackageLicense() -> str:
 	Returns:
 		str: license name
 	"""
-	metaData = getClassifiersLicense()
+	metaData = getMyPackageMetadata()
 	licenseClassifier = licenseFromClassifierlist(metaData.get("classifiers", []))
 	if licenseClassifier != UNKNOWN:
 		return licenseClassifier
 	if "license" in metaData:
 		if isinstance(metaData["license"], dict) and metaData["license"].get("text") is not None:
 			return str(metaData["license"].get("text"))
-		else:
-			return str(metaData["license"])
-	return input("Enter the project license")
+		return str(metaData["license"])
+	return input("Enter the project license\n>")
 
 
 def getModuleSize(path: Path, name: str) -> int:
